#
# spec file for package perl-CGI-FormBuilder
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name CGI-FormBuilder
Name:           perl-CGI-FormBuilder
Version:        3.200.0
Release:        1.2
# 3.20 -> normalize -> 3.200.0
%define cpan_version 3.20
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Easily generate and process stateful forms
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/B/BI/BIGPRESH/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CGI)
Requires:       perl(CGI)
Provides:       perl(CGI::FormBuilder) = %{version}
Provides:       perl(CGI::FormBuilder::Field) = %{version}
Provides:       perl(CGI::FormBuilder::Field::button) = %{version}
Provides:       perl(CGI::FormBuilder::Field::checkbox) = %{version}
Provides:       perl(CGI::FormBuilder::Field::date) = %{version}
Provides:       perl(CGI::FormBuilder::Field::datetime) = %{version}
Provides:       perl(CGI::FormBuilder::Field::datetime_local) = %{version}
Provides:       perl(CGI::FormBuilder::Field::email) = %{version}
Provides:       perl(CGI::FormBuilder::Field::file) = %{version}
Provides:       perl(CGI::FormBuilder::Field::hidden) = %{version}
Provides:       perl(CGI::FormBuilder::Field::image) = %{version}
Provides:       perl(CGI::FormBuilder::Field::number) = %{version}
Provides:       perl(CGI::FormBuilder::Field::password) = %{version}
Provides:       perl(CGI::FormBuilder::Field::radio) = %{version}
Provides:       perl(CGI::FormBuilder::Field::select) = %{version}
Provides:       perl(CGI::FormBuilder::Field::static) = %{version}
Provides:       perl(CGI::FormBuilder::Field::submit) = %{version}
Provides:       perl(CGI::FormBuilder::Field::text) = %{version}
Provides:       perl(CGI::FormBuilder::Field::textarea) = %{version}
Provides:       perl(CGI::FormBuilder::Field::time) = %{version}
Provides:       perl(CGI::FormBuilder::Field::url) = %{version}
Provides:       perl(CGI::FormBuilder::Messages) = %{version}
Provides:       perl(CGI::FormBuilder::Messages::base) = %{version}
Provides:       perl(CGI::FormBuilder::Messages::default) = %{version}
Provides:       perl(CGI::FormBuilder::Messages::locale) = %{version}
Provides:       perl(CGI::FormBuilder::Multi) = %{version}
Provides:       perl(CGI::FormBuilder::Source) = %{version}
Provides:       perl(CGI::FormBuilder::Source::File) = %{version}
Provides:       perl(CGI::FormBuilder::Template) = %{version}
Provides:       perl(CGI::FormBuilder::Template::Builtin) = %{version}
Provides:       perl(CGI::FormBuilder::Template::CGI_SSI) = %{version}
Provides:       perl(CGI::FormBuilder::Template::Div) = %{version}
Provides:       perl(CGI::FormBuilder::Template::Fast) = %{version}
Provides:       perl(CGI::FormBuilder::Template::HTML) = %{version}
Provides:       perl(CGI::FormBuilder::Template::TT2) = %{version}
Provides:       perl(CGI::FormBuilder::Template::Text) = %{version}
Provides:       perl(CGI::FormBuilder::Test) = %{version}
Provides:       perl(CGI::FormBuilder::Util) = %{version}
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
Recommends:     perl(CGI::FastTemplate) >= 1.09
Recommends:     perl(CGI::SSI) >= 0.92
Recommends:     perl(CGI::Session) >= 3.95
Recommends:     perl(HTML::Template) >= 2.06
Recommends:     perl(Template) >= 2.08
Recommends:     perl(Text::Template) >= 1.43
# MANUAL END

%description
If this is your first time using *FormBuilder*, you should check out the
website for tutorials and examples at http://formbuilder.org.

You should also consider joining the google group at
http://groups.google.com/group/perl-formbuilder. There are some pretty
smart people on the list that can help you out.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Thu Sep 19 2024 Tina Müller <timueller+perl@suse.de>
- updated to 3.200.0 (3.20)
  see /usr/share/doc/packages/perl-CGI-FormBuilder/Changes
  3.20, 2024-09-18
  Promoting 3.11 TRIAL release to stable
  (Mark Hedges (MARKLE)'s super bugfixing release)
  Supporting regex modifiers in validation regexes (also MARKLE)
  3.11, 2024-09-13 (TRIAL RELEASE)
  Mark Hedges (MARKLE) fixed some RT bugs.
  RT# 79185   datetime field not working - added messages for 'datetime'
    and 'datetime_local'
  RT# 81650   applied user-supplied patch (thanks) to use deterministic
    field order
  RT# 83012   spanish message error - saved the message file with utf8
    encoding (it was not)
  RT# 87785   ok whatever fixed the typos
  RT# 114018  used utf8::decode instead of Encode::decode(...) no diff in tests
  RT# 155443  use sprintf only if the message has a '%%' for sprintfing
  RT# 155500  js escape single-quotes when validating list of options
* Fri Aug 19 2016 coolo@suse.com
- updated to 3.10
  see /usr/share/doc/packages/perl-CGI-FormBuilder/Changes
* Sun Feb  9 2014 coolo@suse.com
- updated to 3.09 (empty changes file - *shrug*)
* Tue Sep 24 2013 coolo@suse.com
- remove broken tests - no upstream release in 2 years shows...
* Tue Dec  6 2011 coolo@suse.com
- fix perl license
* Fri Nov 18 2011 coolo@suse.com
- update to 3.08
    Maintenance release with a couple new features: support for "charset:
    utf8" in "Source::File", add_before_option/add_after_option c/o Victor
    Porton, and support for HTML5 type names c/o Wolfgang Radke.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Feb 26 2010 chris@computersalat.de
- bzipped Source
- cleanup spec
  o added header
  o sort TAGS
  o fix deps
  o added perl-macros
  o update description
- rpmlint
  o files-duplicate
* Thu Jul 23 2009 lnussel@suse.de
- initial package version 3.0501
